module.exports  ={
    enables:["product","dictionary","category","level"],
    basePackage:"com.simple.server.auto",
    apiServer:"http://api.zhangyongqiao.com",
}

